@@ -18,6 +18,8 @@ __all__ = [
     'ensure_zenodo',
     'update_zenodo',
     'create_zenodo',
+    'download_zenodo',
+    'download_zenodo_latest',
     'Zenodo',
 ]
 
@@ -52,6 +54,16 @@ def update_zenodo(deposition_id: str, paths: Union[str, Iterable[str]], **kwargs
     return Zenodo(**kwargs).update(deposition_id, paths)
 
 
+def download_zenodo(deposition_id: str, path: str, force: bool = False, **kwargs):
+    """Download a Zenodo record."""
+    return Zenodo(**kwargs).download(deposition_id, path=path, force=force)
+
+
+def download_zenodo_latest(deposition_id: str, path: str, force: bool = False, **kwargs):
+    """Download the latest Zenodo record."""
+    return Zenodo(**kwargs).download_latest(deposition_id, path=path, force=force)
+
+
 class Zenodo:
     """A wrapper around parts of the Zenodo API."""
 
@@ -64,14 +76,17 @@ class Zenodo:
         """
         self.sandbox = sandbox
         if self.sandbox:
-            self.base = 'https://sandbox.zenodo.org/api'
+            self.base = 'https://sandbox.zenodo.org'
             self.token_key = 'sandbox_api_token'
         else:
-            self.base = 'https://zenodo.org/api'
+            self.base = 'https://zenodo.org'
             self.token_key = 'api_token'
 
+        # Base URL for the API
+        self.api_base = self.base + '/api'
+
         # Base URL for depositions, relative to the API base
-        self.depositions_base = self.base + '/deposit/depositions'
+        self.depositions_base = self.api_base + '/deposit/depositions'
 
         self.access_token = access_token or pystow.get_config('zenodo', self.token_key)
 
@@ -183,7 +198,7 @@ class Zenodo:
     def get_record(self, record_id: Union[int, str]) -> requests.Response:
         """Get the metadata for a given record."""
         res = requests.get(
-            f'{self.base}/records/{record_id}',
+            f'{self.api_base}/records/{record_id}',
             params={'access_token': self.access_token},
         )
         res.raise_for_status()
@@ -229,7 +244,13 @@ class Zenodo:
         concept_record_id = res_json['conceptrecid']
         version = res_json['metadata']['version']
         logger.debug('version for zenodo.record:%s is %s', record_id, version)
-        url = f'{self.base}/record/{record_id}/files/{path}'
+
+        for file in res_json['files']:
+            if file['key'] == path:
+                url = file['links']['self']
+                break
+        else:
+            raise FileNotFoundError(f'zenodo.record:{record_id} does not have a file with key {path}')
 
         if parts is None:
             parts = ['zenodo', concept_record_id, version, path]
